@@ -13,10 +13,7 @@ use Catalyst::Runtime 5.80;
 #                 directory
 
 use Catalyst qw/
-    -Debug
     FormValidator
-    ConfigLoader
-    Static::Simple
 /;
 
 extends 'Catalyst';
